@@ -1,6 +1,12 @@
 import requests
 import json
 
+
+def error_handler(resource):
+    print(f"Status: {response.status_code}")
+    print(f"ErrorMessage: {response.json()['error']}")
+    return {response.json()['error']}
+
 def create( 
         userID: str, 
         uploadType: str, 
@@ -28,7 +34,10 @@ def create(
     })
 
     response = requests.post(f"{url_path}", headers=headers, data=body) 
-    data = json.loads(response.content)
+    if response.status_code != 200:
+        return error_handler(response)
+    
+    data = response.json()
     
     print("{:<15} {:<5}".format("ID", "Status"))
     print("{:<15} {:<5}".format(data["jobId"], data["status"]))
@@ -37,14 +46,19 @@ def create(
 
 def getList(userID: str, limit = 0):
     url = "http://sdt-api.qcc.svc.cluster.local"
-    url_path = f"{url}/qcc/jobs"
+    url_path = f"{url}/qcc/notebook/jobs"
 
     headers = {
         "Content-Type": "application/json",
         "email": userID,
     }
     response = requests.get(f"{url_path}",headers=headers)
-    data = json.loads(response.content)
+    
+    if response.status_code != 200:
+        return error_handler(response)
+    
+    data = response.json()
+
     print("{:<5} {:<10} {:<10} {:<12} {:<9} {:<8} {:<5} {:<11} {:<17} {:<30} {:<30}".format(
         "ID", 
         "JobID", 
@@ -83,14 +97,18 @@ def getList(userID: str, limit = 0):
 
 def getJob(userID: str, id: int):
     url = "http://sdt-api.qcc.svc.cluster.local"
-    url_path = f"{url}/qcc/job/{id}"
+    url_path = f"{url}/qcc/notebook/job/{id}"
 
     headers = {
         "Content-Type": "application/json",
         "email": userID,
     }
     response = requests.get(f"{url_path}", headers=headers)
-    data = json.loads(response.content)
+    
+    if response.status_code != 200:
+        return error_handler(response)
+
+    data = response.json()
     print("{:<5} {:<10} {:<10} {:<12} {:<9} {:<8} {:<5} {:<11} {:<17} {:<30} {:<30}".format(
         "ID", 
         "JobID", 
@@ -106,17 +124,17 @@ def getJob(userID: str, id: int):
         )
     )
     print("{:<5} {:<10} {:<10} {:<12} {:<9} {:<8} {:<5} {:<11} {:<17} {:<30} {:<30}".format(
-        ele["id"], 
-        ele["jobId"], 
-        ele["resourceId"], 
-        ele["resourceName"], 
-        ele["jobRegStatus"], 
-        ele["jobStatus"], 
-        ele["jobShot"],
-        ele["jobUploadType"],
-        ele["jobFilePath"].split('/')[-1],
-        ele["createdAt"],
-        ele["runningAt"]
+        data["id"], 
+        data["jobId"], 
+        data["resourceId"], 
+        data["resourceName"], 
+        data["jobRegStatus"], 
+        data["jobStatus"], 
+        data["jobShot"],
+        data["jobUploadType"],
+        data["jobFilePath"].split('/')[-1],
+        data["createdAt"],
+        data["runningAt"]
         )
     )
      
@@ -124,13 +142,17 @@ def getJob(userID: str, id: int):
 
 def delete(userID: str, id: str):
     url = "http://sdt-api.qcc.svc.cluster.local"
-    url_path = f"{url}/qcc/job/{id}"
+    url_path = f"{url}/qcc/noteboo/job/{id}"
 
     headers = {
         "Content-Type": "application/json",
         "email": userID,
     }
     response = requests.delete(f"{url_path}", headers=headers)
+    if response.status_code != 200:
+        return error_handler(response)
 
     print(f"Deleted job : {response.text}")
 
+    return response.text
+
